==> deepin-installer-reborn_2.7.14.orig.tar.xz: deepin-installer-reborn-2.7.14/src/ui/frames/inner/select_language_frame.h <==
/*
 * Copyright (C) 2017 ~ 2018 Deepin Technology Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef INSTALLER_UI_FRAMES_SELECT_LANGUAGE_FRAME_H
#define INSTALLER_UI_FRAMES_SELECT_LANGUAGE_FRAME_H

#include "service/system_language.h"

#include <QFrame>
#include <QModelIndex>

class QTranslator;
class QCheckBox;
class QLabel;

namespace installer {

class FramelessListView;
class LanguageListModel;
class NavButton;

// Select system language and update ui language on-the-fly.
class SelectLanguageFrame : public QFrame {
  Q_OBJECT

 public:
  explicit SelectLanguageFrame(QWidget* parent = nullptr);

  // Read default locale.
  void readConf();

  // Write locale to settings file.
  void writeConf();

 signals:
  void finished();

  // Emitted when new language item is selected.
  void timezoneUpdated(const QString& timezone);

  // show UserLicense
  void requestShowUserLicense() const;

 protected:
  // Update text of next_button_
  void changeEvent(QEvent* event) override;

  // Handles key press event of language_view_.
  bool eventFilter(QObject* obj, QEvent* event) Q_DECL_OVERRIDE;

private:
    void initConnections();
    void initUI();
    void updateTranslator(const QString& locale);
    void updateTs();
    void onLanguageListSelected(const QModelIndex& current);
    void onAccpetLicenseChanged(bool enable);

private:
    QTranslator*       current_translator_ = nullptr;
    FramelessListView* language_view_      = nullptr;
    LanguageListModel* language_model_     = nullptr;
    QCheckBox*         accept_license_     = nullptr;
    QLabel*            license_label_      = nullptr;
    NavButton*         next_button_        = nullptr;
    LanguageItem       lang_;  // Current selected language.
  };

}  // namespace installer

#endif  // INSTALLER_UI_FRAMES_SELECT_LANGUAGE_FRAME_H

==> deepin-installer-reborn_5.5.12.orig.tar.xz: deepin-installer-reborn-5.5.12/src/ui/frames/inner/select_language_frame.h <==
/*
 * Copyright (C) 2017 ~ 2018 Deepin Technology Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef INSTALLER_UI_FRAMES_SELECT_LANGUAGE_FRAME_H
#define INSTALLER_UI_FRAMES_SELECT_LANGUAGE_FRAME_H

#include "service/system_language.h"

#include <QFrame>
#include <QModelIndex>
#include <QScopedPointer>

class QTranslator;
class QCheckBox;
class QLabel;

namespace installer {

class LanguageListModel;
class UserAgreementDelegate;
class SelectLanguageFramePrivate;
// Select system language and update ui language on-the-fly.
class SelectLanguageFrame : public QFrame {
  Q_OBJECT

 public:
  explicit SelectLanguageFrame(UserAgreementDelegate * delegate, QWidget* parent = nullptr);
  ~SelectLanguageFrame();

  // Read default locale.
  void readConf();

  // Write locale to settings file.
  void writeConf();

  bool isChecked();
  void acceptLicense(bool accept) const;

 signals:
  // Emitted when new language item is selected.
  void timezoneUpdated(const QString& timezone);

  // show UserLicense
  void requestShowUserLicense() const;

  // show oem UserLicense
  void requestShowOemUserLicense() const;

  void requestNextButtonEnable(bool enable);

  void requestApplyLanguage();

  void requestShowUserExperience();

  void requestPrivacyLicense();

  void coverMainWindowFrameLabelsView(bool cover);

 protected:
  // Update text of next_button_
  void changeEvent(QEvent* event) override;

  // Handles key press event of language_view_.
  bool eventFilter(QObject* obj, QEvent* event) Q_DECL_OVERRIDE;

private:
    QScopedPointer<SelectLanguageFramePrivate> d_private;
    Q_DECLARE_PRIVATE_D(d_private.get(), SelectLanguageFrame);
};

}  // namespace installer

#endif  // INSTALLER_UI_FRAMES_SELECT_LANGUAGE_FRAME_H
